@@ -45,4 +45,4 @@ MeasureOOBError = R6Class("MeasureOOBError",
 )
 
 #' @include mlr_measures.R
-mlr_measures$add("oob_error", MeasureOOBError)
+mlr_measures$add("oob_error", function() MeasureOOBError$new())
