@@ -144,7 +144,7 @@ Task = R6Class("Task",
       )
 
       cn = self$col_info$id # note: this sorts the columns!
-      private$.row_roles = list(use = rn, holdout = integer(), early_stopping = integer())
+      private$.row_roles = list(use = rn, test = integer(), holdout = integer())
       private$.col_roles = named_list(mlr_reflections$task_col_roles[[task_type]], character())
       private$.col_roles$feature = setdiff(cn, self$backend$primary_key)
       self$extra_args = assert_list(extra_args, names = "unique")
@@ -168,6 +168,16 @@ Task = R6Class("Task",
     print = function(...) {
       catf("%s (%i x %i)%s", format(self), self$nrow, self$ncol,
         if (is.null(self$label) || is.na(self$label)) "" else paste0(": ", self$label))
+
+      roles = self$col_roles
+      roles = roles[lengths(roles) > 0L]
+
+      # print additional columns are specified in reflections
+      before = mlr_reflections$task_print_col_roles$before
+      iwalk(before[before %in% names(roles)], function(role, str) {
+        catn(str_indent(sprintf("* %s:", str), role))
+      })
+
       catf(str_indent("* Target:", self$target_names))
       catf(str_indent("* Properties:", self$properties))
 
@@ -182,19 +192,11 @@ Task = R6Class("Task",
         })
       }
 
-      roles = self$col_roles
-      if (length(roles$order)) {
-        catn(str_indent("* Order by:", roles$order))
-      }
-      if ("strata" %in% self$properties) {
-        catn(str_indent("* Strata:", roles$stratum))
-      }
-      if ("groups" %in% self$properties) {
-        catn(str_indent("* Groups:", roles$group))
-      }
-      if ("weights" %in% self$properties) {
-        catn(str_indent("* Weights:", roles$weight))
-      }
+      # print additional columns are specified in reflections
+      after = mlr_reflections$task_print_col_roles$after
+      iwalk(after[after %in% names(roles)], function(role, str) {
+        catn(str_indent(sprintf("* %s:", str), role))
+      })
     },
 
     #' @description
@@ -693,7 +695,7 @@ Task = R6Class("Task",
     hash = function(rhs) {
       private$.hash %??% calculate_hash(
         class(self), self$id, self$backend$hash, self$col_info,
-        private$.row_roles, private$.col_roles, private$.properties
+        remove_named(private$.row_roles, "test"), private$.col_roles, private$.properties
       )
     },
 
@@ -766,16 +768,15 @@ Task = R6Class("Task",
     #' Each row (observation) can have an arbitrary number of roles in the learning task:
     #'
     #' - `"use"`: Use in train / predict / resampling.
+    #' - `"test"`: Observations are hold back unless explicitly queried.
+    #'   Can be queried by a [Learner] to determine a good iteration to stop by evaluating the performance
+    #'   on external data, e.g. the XGboost learner in \CRANpkg{mlr3learners} for parameter `nrounds`.
     #' - `"holdout"`: Observations are hold back unless explicitly queried.
     #'   Can be used, e.g., as truly independent holdout set:
     #'
     #'   1. Add `"holdout"` to the `predict_sets` of a [Learner].
     #'   2. Configure a [Measure] to use the `"holdout"` set by updating its `predict_sets` field.
     #'
-    #' - `"early_stopping"`: Observations are hold back unless explicitly queried.
-    #'   Can be queried by a [Learner] to determine a good iteration to stop by evaluating the performance
-    #'   on external data, e.g. the XGboost learner in \CRANpkg{mlr3learners} for parameter `nrounds`.
-    #'
     #' `row_roles` is a named list whose elements are named by row role and each element is an `integer()` vector of row ids.
     #' To alter the roles, just modify the list, e.g. with  \R's set functions ([intersect()], [setdiff()], [union()], \ldots).
     row_roles = function(rhs) {
