@@ -22,7 +22,7 @@ NULL
 
 load_task_boston_housing = function(id = "boston_housing") {
   b = as_data_backend(load_dataset("BostonHousing2", "mlbench"))
-  task = TaskRegr$new(id, b, target = "medv")
+  task = TaskRegr$new(id, b, target = "medv", label = "Boston Housing Prices")
   b$hash = task$man = "mlr3::mlr_tasks_boston_housing"
   task
 }
