@@ -237,7 +237,7 @@ expect_task = function(task, null_backend_ok = TRUE) {
   lapply(task$col_roles, checkmate::expect_character, any.missing = FALSE, unique = TRUE, min.chars = 1L)
   checkmate::expect_subset(unlist(task$col_roles, use.names = FALSE), task$col_info$id)
 
-  checkmate::expect_list(task$row_roles, names = "unique", types = c("integer", "character"), any.missing = FALSE)
+  checkmate::expect_list(task$row_roles, names = "unique", types = c("integer", "character", "numeric"), any.missing = FALSE)
   checkmate::expect_names(names(task$row_roles), permutation.of = mlr3::mlr_reflections$task_row_roles)
   lapply(task$row_roles, checkmate::expect_integerish, any.missing = FALSE, unique = TRUE)
 
@@ -259,6 +259,10 @@ expect_task = function(task, null_backend_ok = TRUE) {
     missings = task$missings()
     checkmate::expect_integer(missings, names = "unique", any.missing = FALSE, lower = 0L, upper = task$nrow)
 
+    missings = task$missings(character())
+    checkmate::expect_integer(missings, len = 0L)
+    testthat::expect_named(missings)
+
     # query zero columns
     data = task$data(cols = character(), data_format = "data.table")
     checkmate::expect_data_table(data, ncols  = 0L)
